@@ -20,6 +20,7 @@
 #include <log4cxx/spi/loggingevent.h>
 #include <algorithm>
 #include <log4cxx/helpers/pool.h>
+#include <mutex>
 
 using namespace log4cxx;
 using namespace log4cxx::helpers;
@@ -29,23 +30,12 @@ IMPLEMENT_LOG4CXX_OBJECT(AppenderAttachableImpl)
 
 
 AppenderAttachableImpl::AppenderAttachableImpl(Pool& pool)
-	: appenderList(),
-	  mutex(pool)
+	: appenderList()
 {
 }
 
-void AppenderAttachableImpl::addRef() const
-{
-	ObjectImpl::addRef();
-}
 
-void AppenderAttachableImpl::releaseRef() const
-{
-	ObjectImpl::releaseRef();
-}
-
-
-void AppenderAttachableImpl::addAppender(const AppenderPtr& newAppender)
+void AppenderAttachableImpl::addAppender(const AppenderPtr newAppender)
 {
 	// Null values for newAppender parameter are strictly forbidden.
 	if (newAppender == 0)
@@ -53,6 +43,7 @@ void AppenderAttachableImpl::addAppender(const AppenderPtr& newAppender)
 		return;
 	}
 
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::iterator it = std::find(
 			appenderList.begin(), appenderList.end(), newAppender);
 
@@ -66,14 +57,27 @@ int AppenderAttachableImpl::appendLoopOnAppenders(
 	const spi::LoggingEventPtr& event,
 	Pool& p)
 {
-	for (AppenderList::iterator it = appenderList.begin();
-		it != appenderList.end();
+
+	AppenderList allAppenders;
+	int numberAppended = 0;
+	{
+		// There are occasions where we want to modify our list of appenders
+		// while we are iterating over them.  For example, if one of the
+		// appenders fails, we may want to swap it out for a new one.
+		// So, make a local copy of the appenders that we want to iterate over
+		// before actually iterating over them.
+		std::unique_lock<std::mutex> lock( m_mutex );
+		allAppenders = appenderList;
+	}
+	for (AppenderList::iterator it = allAppenders.begin();
+		it != allAppenders.end();
 		it++)
 	{
 		(*it)->doAppend(event, p);
+		numberAppended++;
 	}
 
-	return (int)appenderList.size();
+	return numberAppended;
 }
 
 AppenderList AppenderAttachableImpl::getAllAppenders() const
@@ -88,6 +92,7 @@ AppenderPtr AppenderAttachableImpl::getAppender(const LogString& name) const
 		return 0;
 	}
 
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::const_iterator it, itEnd = appenderList.end();
 	AppenderPtr appender;
 
@@ -104,13 +109,14 @@ AppenderPtr AppenderAttachableImpl::getAppender(const LogString& name) const
 	return 0;
 }
 
-bool AppenderAttachableImpl::isAttached(const AppenderPtr& appender) const
+bool AppenderAttachableImpl::isAttached(const AppenderPtr appender) const
 {
 	if (appender == 0)
 	{
 		return false;
 	}
 
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::const_iterator it = std::find(
 			appenderList.begin(), appenderList.end(), appender);
 
@@ -119,6 +125,7 @@ bool AppenderAttachableImpl::isAttached(const AppenderPtr& appender) const
 
 void AppenderAttachableImpl::removeAllAppenders()
 {
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::iterator it, itEnd = appenderList.end();
 	AppenderPtr a;
 
@@ -131,13 +138,14 @@ void AppenderAttachableImpl::removeAllAppenders()
 	appenderList.clear();
 }
 
-void AppenderAttachableImpl::removeAppender(const AppenderPtr& appender)
+void AppenderAttachableImpl::removeAppender(const AppenderPtr appender)
 {
 	if (appender == 0)
 	{
 		return;
 	}
 
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::iterator it = std::find(
 			appenderList.begin(), appenderList.end(), appender);
 
@@ -154,6 +162,7 @@ void AppenderAttachableImpl::removeAppender(const LogString& name)
 		return;
 	}
 
+	std::unique_lock<std::mutex> lock( m_mutex );
 	AppenderList::iterator it, itEnd = appenderList.end();
 	AppenderPtr appender;
 
