@@ -133,7 +133,8 @@ RolloverDescriptionPtr FixedWindowRollingPolicy::initialize(
 
 	ActionPtr noAction;
 
-	return new RolloverDescription(newActiveFile, append, noAction, noAction);
+	return RolloverDescriptionPtr(
+			new RolloverDescription(newActiveFile, append, noAction, noAction));
 }
 
 /**
@@ -174,31 +175,31 @@ RolloverDescriptionPtr FixedWindowRollingPolicy::rollover(
 	if (StringHelper::endsWith(renameTo, LOG4CXX_STR(".gz")))
 	{
 		renameTo.resize(renameTo.size() - 3);
-		compressAction =
-			new GZCompressAction(
-			File().setPath(renameTo),
-			File().setPath(compressedName),
-			true);
+		compressAction = ActionPtr(
+				new GZCompressAction(
+					File().setPath(renameTo),
+					File().setPath(compressedName),
+					true));
 	}
 	else if (StringHelper::endsWith(renameTo, LOG4CXX_STR(".zip")))
 	{
 		renameTo.resize(renameTo.size() - 4);
-		compressAction =
-			new ZipCompressAction(
-			File().setPath(renameTo),
-			File().setPath(compressedName),
-			true);
+		compressAction = ActionPtr(
+				new ZipCompressAction(
+					File().setPath(renameTo),
+					File().setPath(compressedName),
+					true));
 	}
 
-	FileRenameActionPtr renameAction =
-		new FileRenameAction(
-		File().setPath(currentActiveFile),
-		File().setPath(renameTo),
-		false);
+	FileRenameActionPtr renameAction = FileRenameActionPtr(
+			new FileRenameAction(
+				File().setPath(currentActiveFile),
+				File().setPath(renameTo),
+				false));
 
-	desc = new RolloverDescription(
-		currentActiveFile,  append,
-		renameAction,       compressAction);
+	desc = RolloverDescriptionPtr(new RolloverDescription(
+				currentActiveFile,  append,
+				renameAction,       compressAction));
 
 	return desc;
 }
@@ -235,7 +236,7 @@ bool FixedWindowRollingPolicy::purge(int lowIndex, int highIndex, Pool& p) const
 
 	std::vector<FileRenameActionPtr> renames;
 	LogString buf;
-	ObjectPtr obj = new Integer(lowIndex);
+	ObjectPtr obj = ObjectPtr(new Integer(lowIndex));
 	formatFileName(obj, buf, p);
 
 	LogString lowFilename(buf);
@@ -296,7 +297,7 @@ bool FixedWindowRollingPolicy::purge(int lowIndex, int highIndex, Pool& p) const
 			//   if intermediate index
 			//     add a rename action to the list
 			buf.erase(buf.begin(), buf.end());
-			obj = new Integer(i + 1);
+			obj = ObjectPtr(new Integer(i + 1));
 			formatFileName(obj, buf, p);
 
 			LogString highFilename(buf);
@@ -308,7 +309,7 @@ bool FixedWindowRollingPolicy::purge(int lowIndex, int highIndex, Pool& p) const
 					highFilename.substr(0, highFilename.length() - suffixLength);
 			}
 
-			renames.push_back(new FileRenameAction(*toRename, File().setPath(renameTo), true));
+			renames.push_back(FileRenameActionPtr(new FileRenameAction(*toRename, File().setPath(renameTo), true)));
 			lowFilename = highFilename;
 		}
 		else
