@@ -25,20 +25,18 @@
 #include <log4cxx/helpers/stringhelper.h>
 #include <log4cxx/helpers/serversocket.h>
 #include <log4cxx/spi/loggingevent.h>
-#include <log4cxx/helpers/synchronized.h>
 #include <apr_atomic.h>
 #include <apr_thread_proc.h>
 #include <log4cxx/helpers/objectoutputstream.h>
 #include <log4cxx/helpers/socketoutputstream.h>
 #include <log4cxx/helpers/exception.h>
+#include <mutex>
 
 using namespace log4cxx;
 using namespace log4cxx::helpers;
 using namespace log4cxx::net;
 using namespace log4cxx::spi;
 
-#if APR_HAS_THREADS
-
 IMPLEMENT_LOG4CXX_OBJECT(SocketHubAppender)
 
 int SocketHubAppender::DEFAULT_PORT = 4560;
@@ -85,7 +83,7 @@ void SocketHubAppender::setOption(const LogString& option,
 void SocketHubAppender::close()
 {
 	{
-		LOCK_W sync(mutex);
+		std::unique_lock<log4cxx::shared_mutex> lock(mutex);
 
 		if (closed)
 		{
@@ -96,12 +94,16 @@ void SocketHubAppender::close()
 	}
 
 	LogLog::debug(LOG4CXX_STR("closing SocketHubAppender ") + getName());
+
 	//
 	//  wait until the server thread completes
 	//
-	thread.join();
+	if ( thread.joinable() )
+	{
+		thread.join();
+	}
 
-	LOCK_W sync(mutex);
+	std::unique_lock<log4cxx::shared_mutex> lock(mutex);
 	// close all of the connections
 	LogLog::debug(LOG4CXX_STR("closing client connections"));
 
@@ -175,28 +177,26 @@ void SocketHubAppender::append(const spi::LoggingEventPtr& event, Pool& p)
 
 void SocketHubAppender::startServer()
 {
-	thread.run(monitor, this);
+	thread = std::thread( &SocketHubAppender::monitor, this );
 }
 
-void* APR_THREAD_FUNC SocketHubAppender::monitor(apr_thread_t* /* thread */, void* data)
+void SocketHubAppender::monitor()
 {
-	SocketHubAppender* pThis = (SocketHubAppender*) data;
-
 	ServerSocket* serverSocket = 0;
 
 	try
 	{
-		serverSocket = new ServerSocket(pThis->port);
+		serverSocket = new ServerSocket(port);
 		serverSocket->setSoTimeout(1000);
 	}
 	catch (SocketException& e)
 	{
 		LogLog::error(LOG4CXX_STR("exception setting timeout, shutting down server socket."), e);
 		delete serverSocket;
-		return NULL;
+		return;
 	}
 
-	bool stopRunning = pThis->closed;
+	bool stopRunning = closed;
 
 	while (!stopRunning)
 	{
@@ -233,11 +233,11 @@ void* APR_THREAD_FUNC SocketHubAppender::monitor(apr_thread_t* /* thread */, voi
 					+ LOG4CXX_STR(")"));
 
 				// add it to the oosList.
-				LOCK_W sync(pThis->mutex);
+				std::unique_lock<log4cxx::shared_mutex> lock(mutex);
 				OutputStreamPtr os(new SocketOutputStream(socket));
 				Pool p;
 				ObjectOutputStreamPtr oos(new ObjectOutputStream(os, p));
-				pThis->streams.push_back(oos);
+				streams.push_back(oos);
 			}
 			catch (IOException& e)
 			{
@@ -245,11 +245,8 @@ void* APR_THREAD_FUNC SocketHubAppender::monitor(apr_thread_t* /* thread */, voi
 			}
 		}
 
-		stopRunning = (stopRunning || pThis->closed);
+		stopRunning = (stopRunning || closed);
 	}
 
 	delete serverSocket;
-	return NULL;
 }
-
-#endif
