@@ -30,12 +30,10 @@
 #include <log4cxx/helpers/appenderattachableimpl.h>
 #include <log4cxx/level.h>
 #include <log4cxx/helpers/pool.h>
-#include <log4cxx/helpers/mutex.h>
 #include <log4cxx/spi/location/locationinfo.h>
 #include <log4cxx/helpers/resourcebundle.h>
 #include <log4cxx/helpers/messagebuffer.h>
 
-
 namespace log4cxx
 {
 
@@ -64,7 +62,7 @@ operations, except configuration, are done through this class.
 */
 class LOG4CXX_EXPORT Logger :
 	public virtual log4cxx::spi::AppenderAttachable,
-	public virtual helpers::ObjectImpl
+	public virtual helpers::Object
 {
 	public:
 		DECLARE_ABSTRACT_LOG4CXX_OBJECT(Logger)
@@ -104,7 +102,7 @@ class LOG4CXX_EXPORT Logger :
 
 
 		// Loggers need to know what Hierarchy they are in
-		log4cxx::spi::LoggerRepository* repository;
+		log4cxx::spi::LoggerRepositoryWeakPtr repository;
 
 		helpers::AppenderAttachableImplPtr aai;
 
@@ -136,9 +134,6 @@ class LOG4CXX_EXPORT Logger :
 		~Logger();
 
 
-		void addRef() const;
-		void releaseRef() const;
-
 		/**
 		Add <code>newAppender</code> to the list of appenders of this
 		Logger instance.
@@ -146,7 +141,7 @@ class LOG4CXX_EXPORT Logger :
 		<p>If <code>newAppender</code> is already in the list of
 		appenders, then it won't be added again.
 		*/
-		virtual void addAppender(const AppenderPtr& newAppender);
+		virtual void addAppender(const AppenderPtr newAppender);
 
 
 		/**
@@ -622,13 +617,13 @@ class LOG4CXX_EXPORT Logger :
 
 		@throws RuntimeException if all levels are null in the hierarchy
 		*/
-		virtual const LevelPtr& getEffectiveLevel() const;
+		virtual const LevelPtr getEffectiveLevel() const;
 
 		/**
 		Return the the LoggerRepository where this
 		<code>Logger</code> is attached.
 		*/
-		log4cxx::spi::LoggerRepositoryPtr getLoggerRepository() const;
+		log4cxx::spi::LoggerRepositoryWeakPtr getLoggerRepository() const;
 
 
 		/**
@@ -941,7 +936,7 @@ class LOG4CXX_EXPORT Logger :
 		/**
 		Is the appender passed as parameter attached to this logger?
 		*/
-		bool isAttached(const AppenderPtr& appender) const;
+		bool isAttached(const AppenderPtr appender) const;
 
 		/**
 		 *  Check whether this logger is enabled for the <code>DEBUG</code>
@@ -1452,7 +1447,7 @@ class LOG4CXX_EXPORT Logger :
 		/**
 		Remove the appender passed as parameter form the list of appenders.
 		*/
-		void removeAppender(const AppenderPtr& appender);
+		void removeAppender(const AppenderPtr appender);
 
 		/**
 		Remove the appender with the name passed as parameter form the
@@ -1469,7 +1464,7 @@ class LOG4CXX_EXPORT Logger :
 		friend class Hierarchy;
 		/**
 		Only the Hierarchy class can set the hierarchy of a logger.*/
-		void setHierarchy(spi::LoggerRepository* repository);
+		void setHierarchy(spi::LoggerRepositoryWeakPtr repository);
 
 	public:
 		/**
@@ -1478,7 +1473,7 @@ class LOG4CXX_EXPORT Logger :
 		<p>As in <pre> &nbsp;&nbsp;&nbsp;logger->setLevel(Level::getDebug()); </pre>
 
 		<p>Null values are admitted.  */
-		virtual void setLevel(const LevelPtr& level);
+		virtual void setLevel(const LevelPtr level);
 
 		/**
 		Set the resource bundle to be used with localized logging methods.
@@ -1718,17 +1713,20 @@ class LOG4CXX_EXPORT Logger :
 		*/
 		void trace(const std::string& msg) const;
 
-		inline SHARED_MUTEX& getMutex()
-		{
-			return mutex;
-		}
+		/**
+		 * Reconfigure this logger by configuring all of the appenders.
+		 *
+		 * @param appenders The appenders to set.  Any currently existing appenders are removed.
+		 * @param additivity The additivity of this logger
+		 */
+		void reconfigure( const std::vector<AppenderPtr>& appenders, bool additivity );
 
 	private:
 		//
 		//  prevent copy and assignment
 		Logger(const Logger&);
 		Logger& operator=(const Logger&);
-		mutable SHARED_MUTEX mutex;
+		mutable shared_mutex mutex;
 		friend class log4cxx::helpers::synchronized;
 };
 LOG4CXX_LIST_DEF(LoggerList, LoggerPtr);
@@ -1772,6 +1770,17 @@ Logs a message to a specified logger with a specified level.
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(level, oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
 
+/**
+Logs a message to a specified logger with a specified level, formatting utilizing libfmt
+
+@param logger the logger to be used.
+@param level the level to log.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_LOG_FMT(logger, level, ...) do { \
+		if (logger->isEnabledFor(level)) {\
+			logger->forcedLog(level, fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
+
 /**
 Logs a message to a specified logger with a specified level.
 
@@ -1795,8 +1804,19 @@ Logs a message to a specified logger with the DEBUG level.
 		if (LOG4CXX_UNLIKELY(logger->isDebugEnabled())) {\
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getDebug(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
+
+/**
+Logs a message to a specified logger with the DEBUG level, formatting with libfmt
+
+@param logger the logger to be used.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_DEBUG_FMT(logger, ...) do { \
+		if (LOG4CXX_UNLIKELY(logger->isDebugEnabled())) {\
+			logger->forcedLog(::log4cxx::Level::getDebug(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
 #else
 #define LOG4CXX_DEBUG(logger, message)
+#define LOG4CXX_DEBUG_FMT(logger, ...)
 #endif
 
 #if !defined(LOG4CXX_THRESHOLD) || LOG4CXX_THRESHOLD <= 5000
@@ -1810,8 +1830,19 @@ Logs a message to a specified logger with the TRACE level.
 		if (LOG4CXX_UNLIKELY(logger->isTraceEnabled())) {\
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getTrace(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
+
+/**
+Logs a message to a specified logger with the TRACE level, formatting with libfmt.
+
+@param logger the logger to be used.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_TRACE_FMT(logger, ...) do { \
+		if (LOG4CXX_UNLIKELY(logger->isTraceEnabled())) {\
+			logger->forcedLog(::log4cxx::Level::getTrace(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
 #else
 #define LOG4CXX_TRACE(logger, message)
+#define LOG4CXX_TRACE_FMT(logger, ...)
 #endif
 
 #if !defined(LOG4CXX_THRESHOLD) || LOG4CXX_THRESHOLD <= 20000
@@ -1825,8 +1856,20 @@ Logs a message to a specified logger with the INFO level.
 		if (logger->isInfoEnabled()) {\
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getInfo(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
+
+/**
+Logs a message to a specified logger with the INFO level, formatting with libfmt.
+
+@param logger the logger to be used.
+@param message the message string to log.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_INFO_FMT(logger, ...) do { \
+		if (logger->isInfoEnabled()) {\
+			logger->forcedLog(::log4cxx::Level::getInfo(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
 #else
 #define LOG4CXX_INFO(logger, message)
+#define LOG4CXX_INFO_FMT(logger, ...)
 #endif
 
 #if !defined(LOG4CXX_THRESHOLD) || LOG4CXX_THRESHOLD <= 30000
@@ -1840,8 +1883,19 @@ Logs a message to a specified logger with the WARN level.
 		if (logger->isWarnEnabled()) {\
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getWarn(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
+
+/**
+Logs a message to a specified logger with the WARN level, formatting with libfmt
+
+@param logger the logger to be used.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_WARN_FMT(logger, ...) do { \
+		if (logger->isWarnEnabled()) {\
+			logger->forcedLog(::log4cxx::Level::getWarn(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
 #else
 #define LOG4CXX_WARN(logger, message)
+#define LOG4CXX_WARN_FMT(logger, ...)
 #endif
 
 #if !defined(LOG4CXX_THRESHOLD) || LOG4CXX_THRESHOLD <= 40000
@@ -1856,6 +1910,16 @@ Logs a message to a specified logger with the ERROR level.
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getError(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
 
+/**
+Logs a message to a specified logger with the ERROR level, formatting with libfmt
+
+@param logger the logger to be used.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_ERROR_FMT(logger, ...) do { \
+		if (logger->isErrorEnabled()) {\
+			logger->forcedLog(::log4cxx::Level::getError(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
+
 /**
 Logs a error if the condition is not true.
 
@@ -1868,9 +1932,22 @@ Logs a error if the condition is not true.
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getError(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
 
+/**
+Logs a error if the condition is not true, formatting with libfmt
+
+@param logger the logger to be used.
+@param condition condition
+@param ... The format string and message to log
+*/
+#define LOG4CXX_ASSERT_FMT(logger, condition, ...) do { \
+		if (!(condition) && logger->isErrorEnabled()) {\
+			logger->forcedLog(::log4cxx::Level::getError(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
+
 #else
 #define LOG4CXX_ERROR(logger, message)
+#define LOG4CXX_ERROR_FMT(logger, ...)
 #define LOG4CXX_ASSERT(logger, condition, message)
+#define LOG4CXX_ASSERT_FMT(logger, condition, ...)
 #endif
 
 #if !defined(LOG4CXX_THRESHOLD) || LOG4CXX_THRESHOLD <= 50000
@@ -1884,8 +1961,19 @@ Logs a message to a specified logger with the FATAL level.
 		if (logger->isFatalEnabled()) {\
 			::log4cxx::helpers::MessageBuffer oss_; \
 			logger->forcedLog(::log4cxx::Level::getFatal(), oss_.str(oss_ << message), LOG4CXX_LOCATION); }} while (0)
+
+/**
+Logs a message to a specified logger with the FATAL level, formatting with libfmt
+
+@param logger the logger to be used.
+@param ... The format string and message to log
+*/
+#define LOG4CXX_FATAL_FMT(logger, ...) do { \
+		if (logger->isFatalEnabled()) {\
+			logger->forcedLog(::log4cxx::Level::getFatal(), fmt::format( __VA_ARGS__ ), LOG4CXX_LOCATION); }} while (0)
 #else
 #define LOG4CXX_FATAL(logger, message)
+#define LOG4CXX_FATAL_FMT(logger, ...)
 #endif
 
 /**
