@@ -28,11 +28,12 @@ using namespace log4cxx::spi;
 IMPLEMENT_LOG4CXX_OBJECT(XLogger)
 IMPLEMENT_LOG4CXX_OBJECT(XFactory)
 
-XFactoryPtr XLogger::factory = new XFactory();
+XFactoryPtr XLogger::factory = XFactoryPtr(new XFactory());
 
 void XLogger::lethal(const LogString& message, const LocationInfo& locationInfo)
 {
-	if (repository->isDisabled(XLevel::LETHAL_INT))
+	log4cxx::spi::LoggerRepositoryPtr rep = repository.lock();
+	if (rep->isDisabled(XLevel::LETHAL_INT))
 	{
 		return;
 	}
@@ -45,7 +46,8 @@ void XLogger::lethal(const LogString& message, const LocationInfo& locationInfo)
 
 void XLogger::lethal(const LogString& message)
 {
-	if (repository->isDisabled(XLevel::LETHAL_INT))
+	log4cxx::spi::LoggerRepositoryPtr rep = repository.lock();
+	if (rep->isDisabled(XLevel::LETHAL_INT))
 	{
 		return;
 	}
@@ -68,7 +70,8 @@ LoggerPtr XLogger::getLogger(const helpers::Class& clazz)
 
 void XLogger::trace(const LogString& message, const LocationInfo& locationInfo)
 {
-	if (repository->isDisabled(XLevel::TRACE_INT))
+	log4cxx::spi::LoggerRepositoryPtr rep = repository.lock();
+	if (rep->isDisabled(XLevel::TRACE_INT))
 	{
 		return;
 	}
@@ -81,7 +84,8 @@ void XLogger::trace(const LogString& message, const LocationInfo& locationInfo)
 
 void XLogger::trace(const LogString& message)
 {
-	if (repository->isDisabled(XLevel::TRACE_INT))
+	log4cxx::spi::LoggerRepositoryPtr rep = repository.lock();
+	if (rep->isDisabled(XLevel::TRACE_INT))
 	{
 		return;
 	}
@@ -99,5 +103,5 @@ XFactory::XFactory()
 LoggerPtr XFactory::makeNewLoggerInstance(log4cxx::helpers::Pool& pool,
 	const LogString& name) const
 {
-	return new XLogger(pool, name);
+	return LoggerPtr(new XLogger(pool, name));
 }
