@@ -49,7 +49,10 @@ public:
 
 	void tearDown()
 	{
-		logger->getLoggerRepository()->resetConfiguration();
+		log4cxx::spi::LoggerRepositoryPtr rep = logger->getLoggerRepository().lock();
+		if (rep) {
+			rep->resetConfiguration();
+		}
 	}
 
 	void test1()
