@@ -66,13 +66,16 @@ public:
 
 	void tearDown()
 	{
-		root->getLoggerRepository()->resetConfiguration();
+		log4cxx::spi::LoggerRepositoryPtr rep = root->getLoggerRepository().lock();
+		if (rep) {
+			rep->resetConfiguration();
+		}
 	}
 
 	void simple()
 	{
-		LayoutPtr layout = new SimpleLayout();
-		AppenderPtr appender = new FileAppender(layout, LOG4CXX_STR("output/simple"), false);
+		LayoutPtr layout = LayoutPtr(new SimpleLayout());
+		AppenderPtr appender = FileAppenderPtr(new FileAppender(layout, LOG4CXX_STR("output/simple"), false));
 		root->addAppender(appender);
 		common();
 
@@ -81,9 +84,9 @@ public:
 
 	void ttcc()
 	{
-		LayoutPtr layout =
-			new TTCCLayout(LOG4CXX_STR("DATE"));
-		AppenderPtr appender = new FileAppender(layout, LOG4CXX_STR("output/ttcc"), false);
+		LayoutPtr layout = TTCCLayoutPtr(
+				new TTCCLayout(LOG4CXX_STR("DATE")));
+		AppenderPtr appender = FileAppenderPtr(new FileAppender(layout, LOG4CXX_STR("output/ttcc"), false));
 		root->addAppender(appender);
 		common();
 
