@@ -36,7 +36,7 @@ Num343PatternConverter::Num343PatternConverter() :
 PatternConverterPtr Num343PatternConverter::newInstance(
 	const std::vector<LogString>&)
 {
-	return new Num343PatternConverter();
+	return PatternConverterPtr(new Num343PatternConverter());
 }
 
 
