@@ -93,7 +93,8 @@ public:
 	void tearDown()
 	{
 		MDC::clear();
-		root->getLoggerRepository()->resetConfiguration();
+		log4cxx::spi::LoggerRepositoryPtr rep = root->getLoggerRepository().lock();
+		if (rep) rep->resetConfiguration();
 	}
 
 	void test1()
@@ -441,8 +442,8 @@ public:
 		LogString mdcMsgPattern5 = LOG4CXX_STR("%m : %X{key1},%X{key2},%X{key3}%n");
 
 		// set up appender
-		PatternLayoutPtr layout = new PatternLayout(LOG4CXX_STR("%m%n"));
-		AppenderPtr appender = new FileAppender(layout, OUTPUT_FILE, false);
+		PatternLayoutPtr layout = PatternLayoutPtr(new PatternLayout(LOG4CXX_STR("%m%n")));
+		AppenderPtr appender = FileAppenderPtr(new FileAppender(layout, OUTPUT_FILE, false));
 
 		// set appender on root and set level to debug
 		root->addAppender(appender);
