@@ -16,7 +16,7 @@
  */
 
 #include "vectorappender.h"
-#include <log4cxx/helpers/thread.h>
+#include <thread>
 
 using namespace log4cxx;
 using namespace log4cxx::helpers;
@@ -25,13 +25,7 @@ IMPLEMENT_LOG4CXX_OBJECT(VectorAppender)
 
 void VectorAppender::append(const spi::LoggingEventPtr& event, Pool& /*p*/)
 {
-	try
-	{
-		Thread::sleep(100);
-	}
-	catch (Exception&)
-	{
-	}
+	std::this_thread::sleep_for( std::chrono::milliseconds( 100 ) );
 
 	vector.push_back(event);
 }
